@@ -44,7 +44,9 @@ log = logging.getLogger(__name__)
 
 @task(notifications_disabled=True)
 def import_tool(**kw):
-    GoogleCodeWikiImporter().import_tool(c.project, c.user, **kw)
+    importer = GoogleCodeWikiImporter()
+    with ImportErrorHandler(importer, kw.get('project_name')):
+        importer.import_tool(c.project, c.user, **kw)
 
 
 class GoogleCodeWikiImportForm(ToolImportForm):
@@ -202,14 +204,18 @@ class GoogleCodeWikiImporter(ToolImporter):
                 mount_point=mount_point or 'wiki',
                 mount_label=mount_label or 'Wiki',
                 )
-        with h.push_context(project._id,
-                mount_point=app.config.options.mount_point):
-            for page in self.get_pages(extractor):
-                self.create_page(page)
-                if page.name == default_wiki_page_name:
-                    app.root_page_name = page.name
-        g.post_event('project_updated')
-        return app
+        try:
+            with h.push_context(project._id,
+                    mount_point=app.config.options.mount_point):
+                for page in self.get_pages(extractor):
+                    self.create_page(page)
+                    if page.name == default_wiki_page_name:
+                        app.root_page_name = page.name
+            g.post_event('project_updated')
+            return app
+        except Exception as e:
+            h.make_app_admin_only(app)
+            raise
 
     def get_pages(self, extractor):
         for name, url in extractor.get_wiki_pages():
