@@ -202,6 +202,17 @@ class TestGoogleCodeWikiImporter(TestCase):
         self.assertEqual(Page_upsert.call_count, 1)
         g.post_event.assert_called_once_with('project_updated')
 
+    @patch('googlecodewikiimporter.importer.h')
+    @patch('googlecodewikiimporter.importer.GoogleCodeWikiExtractor')
+    def test_import_tool_failure(self, GoogleCodeWikiExtractor, h):
+        project = Mock()
+        user = Mock()
+        app = project.install_app.return_value
+        h.push_context.side_effect = ValueError
+        self.assertRaises(ValueError, GoogleCodeWikiImporter().import_tool, project, user, project_name='testproject')
+        h.make_app_admin_only.assert_called_once_with(app)
+
+
 
 class TestGoogleCodeWikiImportController(TestController, TestCase):
     def setUp(self):
